#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
from pyramid.view import view_config
from onf_website.component.gallery import Gallery
from onf_website.component.gallery.interfaces import IGalleryContainerTarget, IGallery, IGalleryContainer
from onf_website.component.gallery.zmi.container import GalleryContainerView
from pyams_form.form import AJAXAddForm, AJAXEditForm
from pyams_form.security import ProtectedFormObjectMixin
from pyams_i18n.interfaces import II18n
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.interfaces.viewlet import IWidgetTitleViewletManager
from pyams_skin.layer import IPyAMSLayer
from pyams_skin.viewlet.toolbar import ToolbarAction
from pyams_utils.traversing import get_parent
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDialogAddForm, AdminDialogEditForm

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces

# import packages
from z3c.form import field

from onf_website import _


@viewlet_config(name='add-gallery.menu', context=IGalleryContainerTarget, view=GalleryContainerView,
                layer=IPyAMSLayer, manager=IWidgetTitleViewletManager, weight=50)
class GalleryAddMenu(ProtectedFormObjectMixin, ToolbarAction):
    """Gallery add menu"""

    label = _("Add gallery")

    url = 'add-gallery.html'
    modal_target = True


@pagelet_config(name='add-gallery.html', context=IGalleryContainerTarget, layer=IPyAMSLayer,
                permission='onf.ManageContent')
class GalleryAddForm(AdminDialogAddForm):
    """Gallery add form"""

    legend = _("Add new images gallery")
    icon_css_class = 'fa fa-fw fa-picture-o'

    fields = field.Fields(IGallery).omit('__parent__', '__name__')

    @property
    def ajax_handler(self):
        origin = self.request.params.get('origin')
        if origin == 'link':
            return 'add-gallery-link.json'
        else:
            return 'add-gallery.json'

    edit_permission = 'onf.ManageContent'

    def updateWidgets(self, prefix=None):
        super(GalleryAddForm, self).updateWidgets(prefix)
        self.widgets['description'].label_css_class = 'textarea'

    def create(self, data):
        return Gallery()

    def add(self, object):
        IGalleryContainer(self.context)['none'] = object


@view_config(name='add-gallery.json', context=IGalleryContainerTarget, request_type=IPyAMSLayer,
             permission='onf.ManageContent', renderer='json', xhr=True)
class GalleryAJAXAddForm(AJAXAddForm, GalleryAddForm):
    """Gallery add form, JSON renderer"""

    def get_ajax_output(self, changes):
        return {'status': 'reload',
                'location': '#galleries.html'}


@view_config(name='add-gallery-link.json', context=IGalleryContainerTarget, request_type=IPyAMSLayer,
             permission='onf.ManageContent', renderer='json', xhr=True)
class GalleryLinkAJAXAddForm(AJAXAddForm, GalleryAddForm):
    """Gallery link add form, JSON renderer"""

    def get_ajax_output(self, changes):
        target = get_parent(self.context, IGalleryContainerTarget)
        container = IGalleryContainer(target)
        galleries = [{'id': gallery.__name__,
                      'text': II18n(gallery).query_attribute('title', request=self.request)}
                     for gallery in container.values()]
        return {'status': 'callback',
                'callback': 'ONF.Skin.galleries.refresh',
                'options': {'galleries': galleries,
                            'new_gallery': {'id': changes.__name__,
                                            'text': II18n(changes).query_attribute('title', request=self.request)}}}


@pagelet_config(name='properties.html', context=IGallery, layer=IPyAMSLayer, permission='system.view')
class GalleryPropertiesEditForm(AdminDialogEditForm):
    """Gallery properties edit form"""

    legend = _("Update gallery properties")
    icon_css_class = 'fa fa-fw fa-picture-o'

    fields = field.Fields(IGallery).omit('__parent__', '__file__')
    ajax_handler = 'properties.json'
    edit_permission = 'onf.ManageContent'

    def updateWidgets(self, prefix=None):
        super(GalleryPropertiesEditForm, self).updateWidgets(prefix)
        self.widgets['description'].label_css_class = 'textarea'


@view_config(name='properties.json', context=IGallery, request_type=IPyAMSLayer,
             permission='onf.ManageContent', renderer='json', xhr=True)
class GalleryPropertiesAJAXEditForm(AJAXEditForm, GalleryPropertiesEditForm):
    """Gallery properties edit form, JSON renderer"""

    def get_ajax_output(self, changes):
        if 'title' in changes.get(IGallery, ()):
            return {'status': 'reload',
                    'location': '#external-files.html'}
        else:
            return super(GalleryPropertiesAJAXEditForm, self).get_ajax_output(changes)
