#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from zope.annotation.interfaces import IAttributeAnnotatable
from zope.container.interfaces import IOrderedContainer

# import packages
from pyams_i18n.schema import I18nTextLineField, I18nHTMLField
from zope.container.constraints import containers, contains
from zope.interface import Interface

from onf_website import _


PARAGRAPH_CONTAINER_KEY = 'onf_website.paragraph'


class IBaseParagraph(IAttributeAnnotatable):
    """Base paragraph interface"""

    containers('.IParagraphContainer')

    title = I18nTextLineField(title=_("Title"),
                              description=_("Paragraph title"),
                              required=False)


class IHTMLParagraph(IBaseParagraph):
    """HTML body paragraph"""

    body = I18nHTMLField(title=_("Body"),
                         required=True)


class IParagraphContainer(IOrderedContainer):
    """Paragraphs container"""

    contains(IBaseParagraph)


class IParagraphContainerTarget(Interface):
    """Paragraphs container marker interface"""
