#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.shared.common.interfaces import ISharedToolContainer, ISharedTool, ISharedToolRoles
from pyams_security.interfaces import IDefaultProtectionPolicy
from zope.annotation.interfaces import IAttributeAnnotatable

# import packages
from pyams_security.property import RolePrincipalsFieldProperty
from pyams_security.security import ProtectedObject
from zope.container.folder import Folder
from zope.interface import implementer
from zope.schema.fieldproperty import FieldProperty


@implementer(ISharedToolContainer, IAttributeAnnotatable)
class SharedToolContainer(Folder):
    """Shared tools container"""

    title = FieldProperty(ISharedToolContainer['title'])
    short_name = FieldProperty(ISharedToolContainer['short_name'])


@implementer(IDefaultProtectionPolicy, ISharedTool, ISharedToolRoles, IAttributeAnnotatable)
class SharedTool(ProtectedObject, Folder):
    """Shared tool"""

    __roles__ = ('onf.Webmaster', 'onf.Pilot', 'onf.Manager', 'onf.Contributor')

    roles_interface = ISharedToolRoles

    webmasters = RolePrincipalsFieldProperty(ISharedToolRoles['webmasters'])
    pilots = RolePrincipalsFieldProperty(ISharedToolRoles['pilots'])
    managers = RolePrincipalsFieldProperty(ISharedToolRoles['managers'])
    contributors = RolePrincipalsFieldProperty(ISharedToolRoles['contributors'])

    shared_content_type = None

    title = FieldProperty(ISharedTool['title'])
    short_name = FieldProperty(ISharedTool['short_name'])
