#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
from onf_website.base.interfaces import IBaseContentInfo

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.shared.common.interfaces import IWfSharedContent
from onf_website.zmi.interfaces import ISummaryMenu
from pyams_form.interfaces.form import IWidgetForm, IInnerTabForm
from pyams_sequence.interfaces import ISequentialIdInfo, ISequentialIdTarget, ISequentialIntIds
from pyams_skin.interfaces import IInnerPage, IPageHeader
from pyams_skin.layer import IPyAMSLayer
from pyams_zmi.interfaces.menu import IContentManagementMenu
from pyams_zmi.layer import IAdminLayer
from zope.dublincore.interfaces import IZopeDublinCore

# import packages
from onf_website.shared.common.zmi import WfSharedContentHeaderAdapter
from pyams_form.form import InnerDisplayForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.viewlet.menu import MenuItem
from pyams_utils.adapter import adapter_config
from pyams_utils.date import format_datetime
from pyams_utils.registry import get_utility
from pyams_utils.timezone import tztime
from pyams_utils.traversing import get_parent
from pyams_viewlet.manager import viewletmanager_config
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDisplayForm
from z3c.form import field
from zope.interface import implementer

from onf_website import _


@viewlet_config(name='summary.menu', context=IWfSharedContent, layer=IAdminLayer,
                manager=IContentManagementMenu, permission='system.view', weight=1)
@viewletmanager_config(name='summary.menu', layer=IAdminLayer, provides=ISummaryMenu)
@implementer(ISummaryMenu)
class SharedContentSummaryMenu(MenuItem):
    """Shared content summary menu"""

    label = _("Summary")

    @property
    def badge(self):
        target = get_parent(self.context, ISequentialIdTarget)
        sequence = get_utility(ISequentialIntIds, name=target.sequence_name)
        return sequence.get_short_oid(ISequentialIdInfo(self.context).oid, (target.sequence_prefix or '') + ': ')

    badge_class = 'badge inbox-badge bg-color-red'
    icon_class = 'fa-info-circle'
    url = '#summary.html'


@pagelet_config(name='summary.html', context=IWfSharedContent, layer=IPyAMSLayer, permission='system.view')
@implementer(IWidgetForm, IInnerPage)
class SharedContentSummaryForm(AdminDisplayForm):
    """Shared content summary form"""

    legend = _("Display content summary")
    css_class = 'ams-form form-horizontal form-tight'

    fields = field.Fields(IWfSharedContent).omit('__parent__', '__name__')


@adapter_config(name='dublincore',
                context=(IWfSharedContent, IPyAMSLayer, SharedContentSummaryForm),
                provides=IInnerTabForm)
class SharedContentDublinCoreSummary(InnerDisplayForm):
    """Shared content DublinCore summary"""

    weight = 1
    tab_label = _("Base info.")
    css_class = 'form-tight'

    fields = field.Fields(ISequentialIdInfo).select('hex_oid') + \
             field.Fields(IBaseContentInfo)

    def updateWidgets(self, prefix=None):
        super(SharedContentDublinCoreSummary, self).updateWidgets(prefix)
        info = IBaseContentInfo(self.context)
        self.widgets['created_date'].value = format_datetime(tztime(info.created_date))
        self.widgets['modified_date'].value = format_datetime(tztime(info.modified_date))


@adapter_config(context=(IWfSharedContent, IAdminLayer, SharedContentSummaryForm), provides=IPageHeader)
class SharedContentSummaryHeaderAdapter(WfSharedContentHeaderAdapter):
    """Shared content summary header adapter"""

    icon_class = 'fa fa-fw fa-info-circle'
